searchData={"items":[{"type":"module","title":"Multiverses.Http","doc":"Multiverses suite to enable isolated HTTP communications over multiverse shards\n\n> #","ref":"Multiverses.Http.html"},{"type":"module","title":"You may not need this library {: .warning} - Multiverses.Http","doc":">\n> If you only use `Phoenix.ConnTest` to run your integration tests, you may not\n> need this library.","ref":"Multiverses.Http.html#module-you-may-not-need-this-library-warning"},{"type":"module","title":"How to Use - Multiverses.Http","doc":"#","ref":"Multiverses.Http.html#module-how-to-use"},{"type":"module","title":"In your Phoenix endpoint: - Multiverses.Http","doc":"```\ndefmodule MyAppWeb.Endpoint do\n  #...\n\n  if Mix.env() == :test do\n    plug Multiverses.Plug\n  end\n\n  #...\nend\n```\n\n> ##","ref":"Multiverses.Http.html#module-in-your-phoenix-endpoint"},{"type":"module","title":"Warning {: .warning} - Multiverses.Http","doc":">\n> If you anticipate needing to recompile the Endpoint module on the fly you will need a better way to\n> store the build environment, as the Mix module may not be available to the running VM.\n\n#","ref":"Multiverses.Http.html#module-warning-warning"},{"type":"module","title":"In your test (assuming the `Multiverses.Req` adapter is used) - Multiverses.Http","doc":"- declare that your test shards over the Http multiverses name domain.\n- alias `Multiverses.Req` instead of using the `Req` module.\n\n```elixir\ndefmodule MyAppTest do\n\n  alias Multiverses.Req\n\n  @port #....\n\n  setup do\n    Multiverses.shard(Http)\n  end\n\n  test \"some test\" do\n    result = Req.get(\"localhost:#{@port}\")\n    assert result = #...\n  end\nend\n```","ref":"Multiverses.Http.html#module-in-your-test-assuming-the-multiverses-req-adapter-is-used"},{"type":"module","title":"How it works - Multiverses.Http","doc":"The adapters for the http clients inject the `Multiverses.shard/1` id into\nthe http header `x-multiverse-id`.  This is then intercepted by the\n`Multiverses.Plug` module plug in your Endpoint, which then performs a\nlookup to obtain the `:$callers` for the request; this `:$callers` chain\nis then added to the request process dictionary for the duration of the\nhttp Plug pipeline.\n\nBecause this exchange installs `:$callers` a side effect is that other\nservices that are `:$callers` aware, such as `Mox` or `Ecto` will be able\nto see their respective checkouts.","ref":"Multiverses.Http.html#module-how-it-works"},{"type":"module","title":"Cluster awareness - Multiverses.Http","doc":"`Multiverses.Http` is tested to work over a BEAM cluster.\n\nIf you spin up a cluster as a part of your tests, you can issue an http\nrequest to a node that is *not* the node running `ExUnit` and the `:$callers`\nfor the request will be remote pids (relative to the request handlers).\nBefore proceeding with clustered tests, check to see if the modules that\ndepend on this (e.g. `Mox`, `Ecto`) are able to correctly route their sandbox\ncheckouts to the correct node in the cluster.","ref":"Multiverses.Http.html#module-cluster-awareness"},{"type":"module","title":"Other backends - Multiverses.Http","doc":"Currently there is support only for the `Req` client library.  If support for\nother libraries is desired, please issue a PR.","ref":"Multiverses.Http.html#module-other-backends"},{"type":"function","title":"Multiverses.Http.adopt_callers/1","doc":"finds the current process' `Multiverses` shard (`Http`) id and looks up the\nassociated `:$callers` chain.  This chain is then imported into as the\ncurrent process' `:$callers` chain.\n\nGenerally you would only want to call this function if you are writing a non-\n`Plug` http handler or a websocket server.  In such a case you should call\nthis function immediately after associating the current process with the\nshard using `Multiverses.allow/3` or `Multiverses.allow/2`.","ref":"Multiverses.Http.html#adopt_callers/1"},{"type":"function","title":"Multiverses.Http.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Multiverses.Http.html#child_spec/1"},{"type":"function","title":"Multiverses.Http.init/1","doc":"","ref":"Multiverses.Http.html#init/1"},{"type":"function","title":"Multiverses.Http.registered_id/0","doc":"obtains the `Multiverses` shard (`Http`) id and registers the current calling\nprocess `:$callers` stack, if it has not already been registered.\n\nGenerally you would only want to call this function if you are implementing\nan adapter for an HTTP or websocket client library.","ref":"Multiverses.Http.html#registered_id/0"},{"type":"function","title":"Multiverses.Http.start_link/1","doc":"","ref":"Multiverses.Http.html#start_link/1"},{"type":"module","title":"Multiverses.Plug","doc":"A module `Plug` that intercepts an http request and temporarily assigns the\ncallers stack of the http request to the `Http` shard stored in the\n`x-multiverse-id` header of the http request","ref":"Multiverses.Plug.html"},{"type":"function","title":"Multiverses.Plug.call/2","doc":"","ref":"Multiverses.Plug.html#call/2"},{"type":"function","title":"Multiverses.Plug.init/1","doc":"","ref":"Multiverses.Plug.html#init/1"},{"type":"module","title":"Multiverses.Req","doc":"`Multiverses` shim for the `Req` library.  Implements all functions found in the\n`Req` module, replacing `request`, `delete`, `get`, `head`, `patch`, `post`, and\n`put` (and related functions) with their `Multiverses` equivalent.\n\nMust be used in tandem with `Multiverses.Plug`","ref":"Multiverses.Req.html"},{"type":"function","title":"Multiverses.Req.default_options/0","doc":"","ref":"Multiverses.Req.html#default_options/0"},{"type":"function","title":"Multiverses.Req.default_options/1","doc":"","ref":"Multiverses.Req.html#default_options/1"},{"type":"function","title":"Multiverses.Req.delete/2","doc":"see `Req.delete/2`","ref":"Multiverses.Req.html#delete/2"},{"type":"function","title":"Multiverses.Req.delete!/2","doc":"see `Req.delete!/2`","ref":"Multiverses.Req.html#delete!/2"},{"type":"function","title":"Multiverses.Req.get/2","doc":"see `Req.get/2`","ref":"Multiverses.Req.html#get/2"},{"type":"function","title":"Multiverses.Req.get!/2","doc":"see `Req.get!/2`","ref":"Multiverses.Req.html#get!/2"},{"type":"function","title":"Multiverses.Req.head/2","doc":"see `Req.head/2`","ref":"Multiverses.Req.html#head/2"},{"type":"function","title":"Multiverses.Req.head!/2","doc":"see `Req.head!/2`","ref":"Multiverses.Req.html#head!/2"},{"type":"function","title":"Multiverses.Req.new/0","doc":"","ref":"Multiverses.Req.html#new/0"},{"type":"function","title":"Multiverses.Req.new/1","doc":"","ref":"Multiverses.Req.html#new/1"},{"type":"function","title":"Multiverses.Req.patch/2","doc":"see `Req.patch/2`","ref":"Multiverses.Req.html#patch/2"},{"type":"function","title":"Multiverses.Req.patch!/2","doc":"see `Req.patch!/2`","ref":"Multiverses.Req.html#patch!/2"},{"type":"function","title":"Multiverses.Req.post/2","doc":"see `Req.post/2`","ref":"Multiverses.Req.html#post/2"},{"type":"function","title":"Multiverses.Req.post!/2","doc":"see `Req.post!/2`","ref":"Multiverses.Req.html#post!/2"},{"type":"function","title":"Multiverses.Req.put/2","doc":"see `Req.put/2`","ref":"Multiverses.Req.html#put/2"},{"type":"function","title":"Multiverses.Req.put!/2","doc":"see `Req.put!/2`","ref":"Multiverses.Req.html#put!/2"},{"type":"function","title":"Multiverses.Req.request/1","doc":"","ref":"Multiverses.Req.html#request/1"},{"type":"function","title":"Multiverses.Req.request/2","doc":"","ref":"Multiverses.Req.html#request/2"},{"type":"function","title":"Multiverses.Req.request!/1","doc":"","ref":"Multiverses.Req.html#request!/1"},{"type":"function","title":"Multiverses.Req.request!/2","doc":"","ref":"Multiverses.Req.html#request!/2"},{"type":"function","title":"Multiverses.Req.update/2","doc":"","ref":"Multiverses.Req.html#update/2"},{"type":"extras","title":"Multiverses.Http","doc":"# Multiverses.Http","ref":"readme.html"},{"type":"extras","title":"Installation - Multiverses.Http","doc":"This package can be installed by adding `multiverses_http` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:multiverses, \"~> 0.11\", only: :test},\n    {:multiverses_http, \"~> 0.2\", only: :test}\n  ]\nend\n```\n\nDocumentation can be found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown"}